==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/widgets/table/AddColumnDialog.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

#include "AddColumnDialog.h"

#include "../../../datatype/DateTimeProperty.h"
#include "../../../datatype/SimpleProperty.h"

#include <ui_AddColumnDialogForm.h>

te::dt::Property* GetProperty(const int& propertyType)
{
  if (propertyType == te::dt::DATETIME_TYPE)
  {
    return new te::dt::DateTimeProperty("");
  }
  else
  {
    return new te::dt::SimpleProperty("", propertyType);
  }
}

te::qt::widgets::AddColumnDialog::AddColumnDialog(QWidget* parent) :
QDialog(parent)
{
  m_ui.reset(new Ui::AddColumnDialogForm);
  m_ui->setupUi(this);

  m_ui->m_helpBTN->setPageReference("widgets/table/addColumn.html");

  fillTypes();

  connect(m_ui->m_cancelBTN, SIGNAL(pressed()), SLOT(reject()));
  connect(m_ui->m_okBTN, SIGNAL(pressed()), SLOT(accept()));
}

te::qt::widgets::AddColumnDialog::~AddColumnDialog()
{
}

void te::qt::widgets::AddColumnDialog::fillTypes()
{
  m_ui->m_colTypeCBB->addItem(tr("Integer"), QVariant(te::dt::INT32_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("Real"), QVariant(te::dt::DOUBLE_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("String"), QVariant(te::dt::STRING_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("Date"), QVariant(te::dt::DATETIME_TYPE));
}

te::dt::Property* te::qt::widgets::AddColumnDialog::getNewProperty() const
{
  te::dt::Property* pr = GetProperty(m_ui->m_colTypeCBB->itemData(m_ui->m_colTypeCBB->currentIndex(), Qt::UserRole).toInt());

  pr->setName(m_ui->m_colNameLNE->text().toUtf8().data());

  return pr;
}

void te::qt::widgets::AddColumnDialog::setTableName(const std::string& name)
{
  m_ui->m_tblNameCBB->addItem(name.c_str());
}

==> download.php?FileName=terralib-5.4.0.zip: src/terralib/qt/widgets/table/AddColumnDialog.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

#include "AddColumnDialog.h"

#include "../../../datatype/DateTimeProperty.h"
#include "../../../datatype/SimpleProperty.h"

#include "ui/ui_AddColumnDialogForm.h"

te::dt::Property* GetProperty(const int& propertyType)
{
  if (propertyType == te::dt::DATETIME_TYPE)
  {
    return new te::dt::DateTimeProperty("");
  }
  else
  {
    return new te::dt::SimpleProperty("", propertyType);
  }
}

te::qt::widgets::AddColumnDialog::AddColumnDialog(QWidget* parent) :
QDialog(parent)
{
  m_ui.reset(new Ui::AddColumnDialogForm);
  m_ui->setupUi(this);

  m_ui->m_helpBTN->setPageReference("widgets/table/addColumn.html");

  fillTypes();

  connect(m_ui->m_cancelBTN, SIGNAL(pressed()), SLOT(reject()));
  connect(m_ui->m_okBTN, SIGNAL(pressed()), SLOT(accept()));
}

te::qt::widgets::AddColumnDialog::~AddColumnDialog() = default;

void te::qt::widgets::AddColumnDialog::fillTypes()
{
  m_ui->m_colTypeCBB->addItem(tr("Integer"), QVariant(te::dt::INT32_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("Real"), QVariant(te::dt::DOUBLE_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("String"), QVariant(te::dt::STRING_TYPE));
  m_ui->m_colTypeCBB->addItem(tr("Date"), QVariant(te::dt::DATETIME_TYPE));
}

te::dt::Property* te::qt::widgets::AddColumnDialog::getNewProperty() const
{
  te::dt::Property* pr = GetProperty(m_ui->m_colTypeCBB->itemData(m_ui->m_colTypeCBB->currentIndex(), Qt::UserRole).toInt());

  pr->setName(m_ui->m_colNameLNE->text().toUtf8().data());

  return pr;
}

void te::qt::widgets::AddColumnDialog::setTableName(const std::string& name)
{
  m_ui->m_tblNameCBB->addItem(name.c_str());
}
